diff src/share/vm/code/nmethod.hpp @ 2891:75a99b4f1c98

Rebranded C++ part from C1X to Graal.
author Thomas Wuerthinger <thomas@wuerthinger.net>
date Wed, 08 Jun 2011 14:01:51 +0200
parents 0654ee04b214
children be4ca325525a
line wrap: on
line diff
--- a/src/share/vm/code/nmethod.hpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/code/nmethod.hpp	Wed Jun 08 14:01:51 2011 +0200
@@ -591,9 +591,9 @@
   // Return true is the PC is one would expect if the frame is being deopted.
   bool is_deopt_pc      (address pc) { return is_deopt_entry(pc) || is_deopt_mh_entry(pc); }
 
   // (tw) When using C1X, the address might be off by 5 (because this is the size of the call instruction.
   // (tw) TODO: Replace this by a more general mechanism.
-  bool is_deopt_entry   (address pc) { return pc == deopt_handler_begin() || (UseC1X && pc == deopt_handler_begin() + 5); }
+  bool is_deopt_entry   (address pc) { return pc == deopt_handler_begin() || (UseGraal && pc == deopt_handler_begin() + 5); }
   bool is_deopt_mh_entry(address pc) { return pc == deopt_mh_handler_begin(); }
   // Accessor/mutator for the original pc of a frame before a frame was deopted.
   address get_original_pc(const frame* fr) { return *orig_pc_addr(fr); }
@@ -591,9 +591,9 @@
   bool is_deopt_pc      (address pc) { return is_deopt_entry(pc) || is_deopt_mh_entry(pc); }
 
-  // (tw) When using C1X, the address might be off by 5 (because this is the size of the call instruction.
+  // (tw) When using graal, the address might be off by 5 (because this is the size of the call instruction.
   // (tw) TODO: Replace this by a more general mechanism.